#include <cstdio>
#include <cassert>
#include <algorithm>
#include <cstdlib>
using namespace std;
const int N = (int) 3e5 + 10;
const int inf = (int) 2e9 + 10;
int a[N], b[N], p[N], n, mx = 0;

bool cmp_sum(int i, int j) {
	return a[i] + b[i] > a[j] + b[j];
}

struct node {
	node *l, *r;
	int size, value, max_value, min_value, delta, y;
	node(int value): l(0), r(0), size(1), value(value), max_value(value), min_value(value), delta(0), y((rand() << 16) | rand()) {
	}
};

int get_min_value(node *t) {
	return t ? t->min_value : inf;
}

int get_max_value(node* t) {
	return t ? t->max_value : -inf;
}

int get_size(node* t) {
	return t ? t->size : 0;
}

void update(node *t) {
	assert(t->delta == 0);
	t->size = get_size(t->l) + get_size(t->r) + 1;
	t->min_value = min(get_min_value(t->r), t->value);
	t->max_value = max(get_max_value(t->l), t->value);
}

void apply(node *t, int delta) {
	t->delta += delta, t->value += delta, t->min_value += delta, t->max_value += delta;
}

void push(node *t) {
	if (t->l) apply(t->l, t->delta);
	if (t->r) apply(t->r, t->delta);
	t->delta = 0;
}

void split(node* root, int need, node* &l, node* &r) {
	if (!root) {
		l = r = 0;
	} else {
		if (root->delta) push(root);
		int x = get_size(root->l);
		if (need <= x) {
			split(root->l, need, l, root->l);
			r = root;
		} else {
			split(root->r, need - x - 1, root->r, r);
			l = root;
		}
		update(root);
	}
}

node* merge(node* l, node* r) {
	if (!l) return r;
	if (!r) return l;
	if (l->y < r->y) {
		if (l->delta) push(l);
		l->r = merge(l->r, r);
		update(l);
		return l;
	} else {
		if (r->delta) push(r);
		r->l = merge(l, r->l);
		update(r);
		return r;
	}
}

bool get_greater(node* root, int value, int& j, int& j_value) {
	if (!root) return false;
	if (root->delta) push(root);
	if (root->l && (root->l->min_value - root->value >= value)) {
		if (!get_greater(root->l, value, j, j_value)) {
			j_value = root->l->min_value;
			j = root->l->size - 1;
		}
		return true;
	} else if (root->r && (root->value - root->r->max_value >= value)) {
		j = get_size(root->l);
		j_value = root->value;
		return true;
	}
	bool res = get_greater(root->r, value, j, j_value);
	j += get_size(root->l) + 1;
	return res;
}

int main() {
	scanf("%d", &n);
	for (int i = 0; i < n; ++i)
		scanf("%d%d", &a[i], &b[i]), p[i] = i;
	sort(p, p + n, cmp_sum);
	node *root = new node(inf), *trash, *lpart, *rpart;
	for (int i = 0; i < n; ++i) {
		while ((root->size > 1) && (root->max_value >= a[p[i]] + b[p[i]])) split(root, 1, trash, root);
		
		int j, j_value, extend = min(root->min_value - a[p[i]], b[p[i]]);
		if (get_greater(root, a[p[i]], j, j_value)) {
			split(root, root->size - 1, root, trash);
			split(root, j, lpart, rpart);
			if (rpart) apply(rpart, -a[p[i]]);
			root = merge(lpart, merge(new node(j_value), rpart));
		}
		
		if (root->max_value < b[p[i]]) {
			split(root, 1, trash, root);
			root = merge(new node(b[p[i]]), root);
		}
		
		if (extend >= 0) root = merge(root, new node(extend)), mx++;
	}
	printf("%d\n", mx);
	return 0;
}
